"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AxiosClient = void 0;
const axios_1 = require("axios");
const DrupalError_1 = require("./DrupalError");
class AxiosClient {
    constructor(options = {}) {
        this.client = axios_1.default.create(options);
        this.client.defaults.withCredentials = true;
    }
    setClient(client) {
        this.client = client;
        return this;
    }
    getClient() {
        return this.client;
    }
    addDefaultHeaders(headers) {
        Object.assign(this.client.defaults.headers, headers);
        return this;
    }
    call(method, path, config) {
        const reqCofnig = Object.assign({ method, url: path }, config);
        return this.request(reqCofnig)
            .then((response) => {
            return response;
        }, (response) => {
            throw this.getDrupalError(response);
        });
    }
    request(reqConfig) {
        return this.client.request(reqConfig);
    }
    getDrupalError(response) {
        // Transform the error into an instance of DrupalError by trying to parse
        // the error string as JSON
        let error;
        const data = response.data;
        if (typeof data === 'string' ||
            typeof data === 'undefined' ||
            typeof data === 'number' ||
            typeof data === 'boolean') {
            error = new DrupalError_1.DrupalError(DrupalError_1.DrupalError.CONNECTION_FAILED, `Axios method failed: ${data}`);
        }
        else if (data.responseText === undefined) {
            error = new DrupalError_1.DrupalError(DrupalError_1.DrupalError.CONNECTION_FAILED, `Axios method failed: ${JSON.stringify(data)}`);
        }
        else if (typeof data.responseText === 'string') {
            try {
                const errorJSON = JSON.parse(data.responseText);
                error = new DrupalError_1.DrupalError(errorJSON.code, errorJSON.error);
            }
            catch (exception) {
                // If we fail to parse the error text, that's okay.
                error = new DrupalError_1.DrupalError(DrupalError_1.DrupalError.INVALID_JSON, `Received an error with invalid JSON from Drupal: ${data.responseText}`);
            }
        }
        else {
            error = new DrupalError_1.DrupalError(DrupalError_1.DrupalError.INVALID_JSON, `Received an error with invalid JSON from Drupal: ${data.responseText}`);
        }
        return error;
    }
}
exports.AxiosClient = AxiosClient;
