"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DrupalAuth = void 0;
class DrupalAuth {
    constructor(drupal) {
        this.drupal = drupal;
        this.client = drupal.getClient();
        this.store = {};
        this.refreshUserSession();
    }
    refreshUserSession() {
        this.store = {
            csrfToken: undefined,
            logoutToken: undefined,
            currentUser: {
                uid: '0',
                roles: ['anonymous'],
                name: 'Anonymous',
            },
        };
        return this.getSessionToken();
    }
    getSessionToken() {
        const config = {
            headers: {
                'Content-Type': 'application/json',
            },
            withCredentials: true,
        };
        return this.client
            .call('get', '/session/token', config)
            .then((response) => {
            const data = response.data;
            this.store.csrfToken = data;
            this.client.addDefaultHeaders({ 'X-CSRF-Token': data });
            return response;
        });
    }
    login(name, pass) {
        const config = {
            headers: {
                'Content-Type': 'application/json',
            },
            withCredentials: true,
            params: {
                _format: 'json',
            },
            data: {
                name,
                pass,
            },
        };
        return this.client
            .call('post', '/user/login', config)
            .then((response) => {
            const data = response.data;
            this.store = data;
            this.client.addDefaultHeaders({ 'X-CSRF-Token': data.csrfToken });
            return response;
        });
    }
    loginStatus() {
        const config = {
            headers: {
                'Content-Type': 'application/json',
            },
            withCredentials: true,
            params: {
                _format: 'json',
            },
        };
        return this.client
            .call('get', '/user/login_status', config)
            .then((response) => {
            return response.data !== 0;
        });
    }
    forcedLogout() {
        if (this.store.logoutToken) {
            return this.logout()
                // @TODO Reset user is authenticated status.
                .then(() => true);
        }
        const config = {
            withCredentials: true,
        };
        return this.client
            .call('get', '/user/logout', config)
            // @TODO Reset user is authenticated status.
            .then(() => true);
    }
    logout() {
        const config = {
            headers: {
                'Content-Type': 'application/json',
            },
            withCredentials: true,
            params: {
                _format: 'json',
                token: this.store.logoutToken,
            },
        };
        return this.client
            .call('post', '/user/logout', config)
            .then((response) => {
            // @TODO Reset user is authenticated status.
            return response;
        });
    }
    passwordResetByUserName(name) {
        const config = {
            headers: {
                'Content-Type': 'application/json',
            },
            withCredentials: true,
            params: {
                _format: 'json',
            },
            data: {
                name,
            },
        };
        return this.client
            .call('post', '/user/password', config)
            .then((response) => {
            // @TODO Reset user is authenticated status.
            return response;
        });
    }
    passwordResetByMail(mail) {
        const config = {
            headers: {
                'Content-Type': 'application/json',
            },
            withCredentials: true,
            params: {
                _format: 'json',
            },
            data: {
                mail,
            },
        };
        return this.client
            .call('post', '/user/password', config)
            .then((response) => {
            // @TODO Reset user is authenticated status.
            return response;
        });
    }
    register(name, mail) {
        const config = {
            headers: {
                'Content-Type': 'application/json',
            },
            withCredentials: true,
            params: {
                _format: 'json',
            },
            data: {
                name: {
                    value: name,
                },
                mail: {
                    value: mail,
                },
            },
        };
        return this.client
            .call('post', '/user/register', config)
            .then((response) => {
            // @TODO Reset user is authenticated status.
            return response;
        });
    }
}
exports.DrupalAuth = DrupalAuth;
