/**
 * Constructs a new Drupal.Error object with the given code and message.
 */
export declare class DrupalError extends Error {
    /**
     * Error code indicating some error other than those enumerated here.
     */
    static readonly UNDEFINED: number;
    /**
     * Error code indicating that something has gone wrong with the server.
     */
    static readonly INTERNAL_SERVER_ERROR: number;
    /**
     * Error code indicating the sdk has encountered a missing implementation.
     */
    static readonly MISSING_IMPLEMENTATION_ERROR: number;
    /**
     * Error code indicating the connection to the Drupal server failed.
     */
    static readonly CONNECTION_FAILED: number;
    /**
     * Error code indicating the specified object doesn't exist.
     */
    static readonly OBJECT_NOT_FOUND: number;
    /**
     * Error code indicating you tried to query with a datatype that doesn't
     * support it, like exact matching an array or object.
     */
    static readonly INVALID_QUERY: number;
    /**
     * Error code indicating a missing or invalid classname. Classnames are
     * case-sensitive. They must start with a letter, and a-zA-Z0-9_ are the
     * only valid characters.
     */
    static readonly INVALID_CLASS_NAME: number;
    /**
     * Error code indicating an unspecified object id.
     */
    static readonly MISSING_OBJECT_ID: number;
    /**
     * Error code indicating an invalid key name. Keys are case-sensitive. They
     * must start with a letter, and a-zA-Z0-9_ are the only valid characters.
     */
    static readonly INVALID_KEY_NAME: number;
    /**
     * Error code indicating a malformed pointer. You should not see this unless
     * you have been mucking about changing internal Drupal code.
     */
    static readonly INVALID_POINTER: number;
    /**
     * Error code indicating that badly formed JSON was received upstream. This
     * either indicates you have done something unusual with modifying how
     * things encode to JSON, or the network is failing badly.
     */
    static readonly INVALID_JSON: number;
    /**
     * Error code indicating that the feature you tried to access is only
     * available internally for testing purposes.
     */
    static readonly COMMAND_UNAVAILABLE: number;
    /**
     * You must call Drupal.initialize before using the Drupal library.
     */
    static readonly NOT_INITIALIZED: number;
    /**
     * Error code indicating that a field was set to an inconsistent type.
     */
    static readonly INCORRECT_TYPE: number;
    /**
     * Error code indicating an invalid channel name. A channel name is either
     * an empty string (the broadcast channel) or contains only a-zA-Z0-9_
     * characters and starts with a letter.
     */
    static readonly INVALID_CHANNEL_NAME: number;
    /**
     * Error code indicating that push is misconfigured.
     */
    static readonly PUSH_MISCONFIGURED: number;
    /**
     * Error code indicating that the object is too large.
     */
    static readonly OBJECT_TOO_LARGE: number;
    /**
     * Error code indicating that the operation isn't allowed for clients.
     */
    static readonly OPERATION_FORBIDDEN: number;
    /**
     * Error code indicating the result was not found in the cache.
     */
    static readonly CACHE_MISS: number;
    /**
     * Error code indicating that an invalid key was used in a nested
     * JSONObject.
     */
    static readonly INVALID_NESTED_KEY: number;
    /**
     * Error code indicating that an invalid filename was used for DrupalFile.
     * A valid file name contains only a-zA-Z0-9_. characters and is between 1
     * and 128 characters.
     */
    static readonly INVALID_FILE_NAME: number;
    /**
     * Error code indicating an invalid ACL was provided.
     */
    static readonly INVALID_ACL: number;
    /**
     * Error code indicating that the request timed out on the server. Typically
     * this indicates that the request is too expensive to run.
     */
    static readonly TIMEOUT: number;
    /**
     * Error code indicating that the email address was invalid.
     */
    static readonly INVALID_EMAIL_ADDRESS: number;
    /**
     * Error code indicating a missing content type.
     */
    static readonly MISSING_CONTENT_TYPE: number;
    /**
     * Error code indicating a missing content length.
     */
    static readonly MISSING_CONTENT_LENGTH: number;
    /**
     * Error code indicating an invalid content length.
     */
    static readonly INVALID_CONTENT_LENGTH: number;
    /**
     * Error code indicating a file that was too large.
     */
    static readonly FILE_TOO_LARGE: number;
    /**
     * Error code indicating an error saving a file.
     */
    static readonly FILE_SAVE_ERROR: number;
    /**
     * Error code indicating that a unique field was given a value that is
     * already taken.
     */
    static readonly DUPLICATE_VALUE: number;
    /**
     * Error code indicating that a role's name is invalid.
     */
    static readonly INVALID_ROLE_NAME: number;
    /**
     * Error code indicating that an application quota was exceeded.  Upgrade to
     * resolve.
     */
    static readonly EXCEEDED_QUOTA: number;
    /**
     * Error code indicating that a Cloud Code script failed.
     */
    static readonly SCRIPT_FAILED: number;
    /**
     * Error code indicating that a Cloud Code validation failed.
     */
    static readonly VALIDATION_ERROR: number;
    /**
     * Error code indicating that invalid image data was provided.
     */
    static readonly INVALID_IMAGE_DATA: number;
    /**
     * Error code indicating an unsaved file.
     */
    static readonly UNSAVED_FILE_ERROR: number;
    /**
     * Error code indicating an invalid push time.
     */
    static readonly INVALID_PUSH_TIME_ERROR: number;
    /**
     * Error code indicating an error deleting a file.
     */
    static readonly FILE_DELETE_ERROR: number;
    /**
     * Error code indicating an error deleting an unnamed file.
     */
    static readonly FILE_DELETE_UNNAMED_ERROR: number;
    /**
     * Error code indicating that the application has exceeded its request
     * limit.
     */
    static readonly REQUEST_LIMIT_EXCEEDED: number;
    /**
     * Error code indicating that the request was a duplicate and has been discarded due to
     * idempotency rules.
     */
    static readonly DUPLICATE_REQUEST: number;
    /**
     * Error code indicating an invalid event name.
     */
    static readonly INVALID_EVENT_NAME: number;
    /**
     * Error code indicating that a field had an invalid value.
     */
    static readonly INVALID_VALUE: number;
    /**
     * Error code indicating that the username is missing or empty.
     */
    static readonly USERNAME_MISSING: number;
    /**
     * Error code indicating that the password is missing or empty.
     */
    static readonly PASSWORD_MISSING: number;
    /**
     * Error code indicating that the username has already been taken.
     */
    static readonly USERNAME_TAKEN: number;
    /**
     * Error code indicating that the email has already been taken.
     */
    static readonly EMAIL_TAKEN: number;
    /**
     * Error code indicating that the email is missing, but must be specified.
     */
    static readonly EMAIL_MISSING: number;
    /**
     * Error code indicating that a user with the specified email was not found.
     */
    static readonly EMAIL_NOT_FOUND: number;
    /**
     * Error code indicating that a user object without a valid session could
     * not be altered.
     */
    static readonly SESSION_MISSING: number;
    /**
     * Error code indicating that a user can only be created through signup.
     */
    static readonly MUST_CREATE_USER_THROUGH_SIGNUP: number;
    /**
     * Error code indicating that an an account being linked is already linked
     * to another user.
     */
    static readonly ACCOUNT_ALREADY_LINKED: number;
    /**
     * Error code indicating that the current session token is invalid.
     */
    static readonly INVALID_SESSION_TOKEN: number;
    /**
     * Error code indicating an error enabling or verifying MFA
     */
    static readonly MFA_ERROR: number;
    /**
     * Error code indicating that a valid MFA token must be provided
     */
    static readonly MFA_TOKEN_REQUIRED: number;
    /**
     * Error code indicating that a user cannot be linked to an account because
     * that account's id could not be found.
     */
    static readonly LINKED_ID_MISSING: number;
    /**
     * Error code indicating that a user with a linked (e.g. Facebook) account
     * has an invalid session.
     */
    static readonly INVALID_LINKED_SESSION: number;
    /**
     * Error code indicating that a service being linked (e.g. Facebook or
     * Twitter) is unsupported.
     */
    static readonly UNSUPPORTED_SERVICE: number;
    /**
     * Error code indicating an invalid operation occured on schema
     */
    static readonly INVALID_SCHEMA_OPERATION: number;
    /**
     * Error code indicating that there were multiple errors. Aggregate errors
     * have an "errors" property, which is an array of error objects with more
     * detail about each error that occurred.
     */
    static readonly AGGREGATE_ERROR: number;
    /**
     * Error code indicating the client was unable to read an input file.
     */
    static readonly FILE_READ_ERROR: number;
    /**
     * Error code indicating a real error code is unavailable because
     * we had to use an XDomainRequest object to allow CORS requests in
     * Internet Explorer, which strips the body from HTTP responses that have
     * a non-2XX status code.
     */
    static readonly X_DOMAIN_REQUEST: number;
    /**
     * An error code from <code>Drupal.Error</code>.
     */
    code: number;
    /**
     * @param {number} code An error code constant from <code>Drupal.Error</code>.
     * @param {string} message A detailed description of the error.
     */
    constructor(code: number, message: string);
    /**
     * Get the error code.
     * @returns error code.
     */
    getErrorCode(): number;
    /**
     * Drupal error message.
     * @returns Error message.
     */
    toString(): string;
}
