"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DrupalMenu = void 0;
const DrupalError_1 = require("./DrupalError");
/**
 * Constructs a new Drupal.Menu object with the given code and message.
 */
class DrupalMenu {
    constructor(drupal) {
        this.drupal = drupal;
        this.client = drupal.getClient();
    }
    getMenu(menuName) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.getMenuRaw(menuName)
                .then((res) => {
                const data = res.data;
                if (this.checkIfDrupalMenuDataIsValid(data)) {
                    const normalizedItems = this.normalizeListItems(data);
                    return this.convertFlatListItemsToTree(normalizedItems);
                }
                else {
                    throw new DrupalError_1.DrupalError(DrupalError_1.DrupalError.INVALID_JSON, 'Menu data is invalid');
                }
            });
        });
    }
    getMenuRaw(menuName) {
        return this.client.call('get', `/system/menu/${menuName}/linkset`);
    }
    /**
     * Normalize Drupal array.
     * So that we can feed it into an algorithm that was copy-pasted from stack overflow.
     */
    normalizeListItems(data) {
        const list = [];
        if (this.checkIfDrupalMenuDataIsValid(data)) {
            const items = data.linkset[0].item;
            items.map((item) => {
                let parentId;
                let level;
                const id = `${item['drupal-menu-machine-name'][0]}${item['drupal-menu-hierarchy'][0]}`;
                const idArray = id.split('.');
                idArray.pop();
                parentId = idArray.join('.');
                level = 0;
                level = idArray.length;
                if (level < 2) {
                    parentId = '0';
                }
                const node = {
                    id,
                    parentId,
                    name: item.title,
                    href: item.href,
                    level,
                    items: null,
                };
                list.push(node);
            });
        }
        return list;
    }
    /**
     * Check if menu data is valid.
     */
    checkIfDrupalMenuDataIsValid(data) {
        if (data !== undefined &&
            data.linkset !== undefined &&
            data.linkset[0] !== undefined &&
            data.linkset[0].item !== undefined) {
            return true;
        }
        else {
            return false;
        }
    }
    /**
     * Convert Flat list to Tre structure.
     */
    convertFlatListItemsToTree(inputList) {
        const roots = [];
        if (inputList.length === 0) {
            return roots;
        }
        const myObjMap = {};
        inputList.map((node, index) => {
            myObjMap[node.id] = index;
            inputList[index].items = [];
        });
        inputList.map((node) => {
            if (node.parentId === '0') {
                roots.push(node);
            }
            else {
                inputList[myObjMap[node.parentId]].items.push(node);
            }
        });
        return roots;
    }
}
exports.DrupalMenu = DrupalMenu;
